@@ -104,7 +104,7 @@ submodule of the general StreamFinder module.
 
 Depends:  
 
-L<I::Escape>, L<HTML::Entities>, L<LWP::UserAgent>, 
+L<URI::Escape>, L<HTML::Entities>, L<LWP::UserAgent>, 
 and the separate application program:  youtube-dl.
 
 =head1 SUBROUTINES/METHODS
@@ -387,13 +387,19 @@ sub new
 	}
 	my $player_url = 'https://player.vimeo.com/video/'. $self->{'id'};
 	print STDERR "-1 FETCHING URL=$player_url= ID=".$self->{'id'}."=\n"  if ($DEBUG);
-	$self->{'iconurl'} = '';
 	$self->{'title'} = '';
-	$self->{'description'} = '';
 	$self->{'artist'} = '';
-	$self->{'albumartist'} = '';
+	$self->{'album'} = '';
+	$self->{'description'} = '';
+	$self->{'created'} = '';
+	$self->{'year'} = '';
+	$self->{'genre'} = 'Video';
+	$self->{'iconurl'} = '';
 	$self->{'streams'} = [];
 	$self->{'cnt'} = 0;
+	$self->{'Url'} = '';
+	$self->{'playlist'} = '';
+	$self->{'albumartist'} = $player_url;
 
 	#VIMEO VIDEOS BEST SCANNED MANUALLY!:
 
